@@ -29,7 +29,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2015  Craig Barratt
+#   Copyright (C) 2001-2017  Craig Barratt
 #
 #   See http://backuppc.sourceforge.net.
 #
@@ -2104,7 +2104,7 @@ $Conf{CgiNavBarLinks} = [
         lname => "Documentation",    # actually displays $Lang->{Documentation}
     },
     {
-        link  => "http://backuppc.wiki.sourceforge.net",
+        link  => "https://github.com/backuppc/backuppc/wiki",
         name  => "Wiki",              # displays literal "Wiki"
     },
     {
